<?php

namespace apexl\Io\modules\user\entities;

use apexl\Io\includes\Entity;
use apexl\Io\modules\user\entities\operators\refreshTokenOperator;
use apexl\Io\modules\user\entities\operators\userNoteOperator;
use apexl\Io\operators\entityDatabaseOperator;

class userNoteEntity extends Entity
{
    public function __construct()
    {
        parent::__construct('user_notes');
        $this->setOperator(new userNoteOperator('user_notes', 'id'));
    }
}
